package com.example.julian.endlessroll.entities.tileLists;

import com.example.julian.endlessroll.entities.textures.Texture;
import com.example.julian.endlessroll.levels.TileData;

import java.util.ArrayList;
import java.util.List;

@SuppressWarnings("serial")
public class TileList extends ArrayList<Tile> {

    public enum Type {
        TERRAIN, CEILING;

        public float calculateTileHeightFromEdge(float edge) {
            switch (this) {
                case TERRAIN:
                    return 1 + edge;
                case CEILING:
                    return 1 - edge;
            }
            return 0;
        }

    }

    private Type type;
    private Texture texture;
    private float edge;
    private boolean endless;

    public TileList(Type type, Texture texture) {
        this.type = type;
        this.texture = texture;
    }

    public void loadData(float edge, List<TileData> tileData) {
        this.endless = false;
        super.clear();
        for (TileData data : tileData)
            super.add(new Tile(type, texture, edge, data));
        this.edge = edge;
    }

    public void createEndless(float edge) {
        loadData(edge, new ArrayList<TileData>());
        super.add(createEndlessTile(0));
        this.endless = true;
    }

    public void update(float cameraX) {
        if (!super.isEmpty()) {
            if (endless) {
                Tile last = super.get(super.size() - 1);
                if (last.getRightEdge() - cameraX < 3)
                    super.add(createEndlessTile(last.getRightEdge() + 2.5f));
            }
            if (super.get(0).getRightEdge() - cameraX < -3) {
                super.remove(0);
            }
        }
    }

    private Tile createEndlessTile(float x) {
        return new Tile(type, texture, edge, x, 5);
    }

    public float getEdge() {
        return edge;
    }

}
